Crate bock_core

Crate bock_core 

Bock core — core standard library primitives, collections, monadic types, iterators, and built-in operations.

This crate populates the interpreter’s BuiltinRegistry with the full method suites for primitive types (Int, Float, Bool, String, Char), collection types (List, Map, Set), monadic types (Optional, Result), iterator protocol (lazy combinators: map, filter, take, skip, enumerate, zip, chain, collect), and their core trait implementations (Comparable, Equatable, Hashable, Displayable).

Re-exports

pub use traits::ConversionDirection;
pub use traits::TraitDispatch;

Modules

adaptive
Adaptive effect handlers (10.8).
collections
Collection type method registrations.
concurrency
Core concurrency module — registers Channel[T] and spawn.
effect
Stub module for core.effect.
error
Stub module for core.error.
iterator
Iterator protocol methods and combinators.
math
Stub module for core.math.
memory
Stub module for core.memory.
option_result
Optional and Result type method registrations.
primitives
Primitive type method registrations.
string_builder
StringBuilder type for efficient string concatenation.
test
Stub module for core.test.
time
Core time module — registers the sleep prelude function.
traits
Core trait dispatch — maps language features to trait method calls.

Functions

register_core
Register all primitive, collection, and monadic type methods and trait implementations into the given BuiltinRegistry.