pub fn register_core(registry: &mut BuiltinRegistry)Expand description
Register all primitive, collection, and monadic type methods and trait
implementations into the given BuiltinRegistry.
Call this during interpreter initialization to make all built-in methods available.